==> kdevelop-24.08.2-x86_64-2_KDE6.txz: usr/lib64/cmake/KDevPlatform/KDevPlatformTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDev::Sublime" for configuration "Release"
set_property(TARGET KDev::Sublime APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Sublime PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::KIOWidgets;KF6::I18n;KF6::TextWidgets"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKDevPlatformSublime.so.6.0.240802"
  IMPORTED_SONAME_RELEASE "libKDevPlatformSublime.so.60"
  )

list(APPEND _cmake_import_check_targets KDev::Sublime )
list(APPEND _cmake_import_check_files_for_KDev::Sublime "${_IMPORT_PREFIX}/lib64/libKDevPlatformSublime.so.6.0.240802" )

# Import target "KDev::Interfaces" for configuration "Release"
set_property(TARGET KDev::Interfaces APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Interfaces PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::Service"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKDevPlatformInterfaces.so.6.0.240802"
  IMPORTED_SONAME_RELEASE "libKDevPlatformInterfaces.so.60"
  )

list(APPEND _cmake_import_check_targets KDev::Interfaces )
list(APPEND _cmake_import_check_files_for_KDev::Interfaces "${_IMPORT_PREFIX}/lib64/libKDevPlatformInterfaces.so.6.0.240802" )

# Import target "KDev::Project" for configuration "Release"
set_property(TARGET KDev::Project APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Project PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Serialization;KDev::Sublime;KF6::KIOWidgets"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKDevPlatformProject.so.6.0.240802"
  IMPORTED_SONAME_RELEASE "libKDevPlatformProject.so.60"
  )

list(APPEND _cmake_import_check_targets KDev::Project )
list(APPEND _cmake_import_check_files_for_KDev::Project "${_IMPORT_PREFIX}/lib64/libKDevPlatformProject.so.6.0.240802" )

# Import target "KDev::Language" for configuration "Release"
set_property(TARGET KDev::Language APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Language PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Project;KDev::Sublime;KF6::GuiAddons;KF6::TextEditor;KF6::Parts;KF6::Archive;KF6::TextTemplate"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKDevPlatformLanguage.so.6.0.240802"
  IMPORTED_SONAME_RELEASE "libKDevPlatformLanguage.so.60"
  )

list(APPEND _cmake_import_check_targets KDev::Language )
list(APPEND _cmake_import_check_files_for_KDev::Language "${_IMPORT_PREFIX}/lib64/libKDevPlatformLanguage.so.6.0.240802" )

# Import target "KDev::Shell" for configuration "Release"
set_property(TARGET KDev::Shell APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Shell PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Debugger;KDev::Project;KDev::Vcs;KDev::Util;KDev::Documentation;KF6::GuiAddons;KF6::ConfigWidgets;KF6::KIOFileWidgets;KF6::KIOWidgets;KF6::Parts;KF6::Notifications;KF6::NotifyConfig;KF6::TextEditor;KF6::JobWidgets;KF6::ItemViews;KF6::WindowSystem;KF6::TextWidgets;KF6::KCMUtils;KF6::NewStuffWidgets;KF6::Archive"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKDevPlatformShell.so.6.0.240802"
  IMPORTED_SONAME_RELEASE "libKDevPlatformShell.so.60"
  )

list(APPEND _cmake_import_check_targets KDev::Shell )
list(APPEND _cmake_import_check_files_for_KDev::Shell "${_IMPORT_PREFIX}/lib64/libKDevPlatformShell.so.6.0.240802" )

# Import target "KDev::Util" for configuration "Release"
set_property(TARGET KDev::Util APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Util PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::ItemModels;KF6::GuiAddons"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKDevPlatformUtil.so.6.0.240802"
  IMPORTED_SONAME_RELEASE "libKDevPlatformUtil.so.60"
  )

list(APPEND _cmake_import_check_targets KDev::Util )
list(APPEND _cmake_import_check_files_for_KDev::Util "${_IMPORT_PREFIX}/lib64/libKDevPlatformUtil.so.6.0.240802" )

# Import target "KDev::OutputView" for configuration "Release"
set_property(TARGET KDev::OutputView APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::OutputView PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Interfaces;KDev::Util"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKDevPlatformOutputView.so.6.0.240802"
  IMPORTED_SONAME_RELEASE "libKDevPlatformOutputView.so.60"
  )

list(APPEND _cmake_import_check_targets KDev::OutputView )
list(APPEND _cmake_import_check_files_for_KDev::OutputView "${_IMPORT_PREFIX}/lib64/libKDevPlatformOutputView.so.6.0.240802" )

# Import target "KDev::Vcs" for configuration "Release"
set_property(TARGET KDev::Vcs APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Vcs PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Util;KF6::KIOWidgets;KF6::Parts;KF6::TextWidgets"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKDevPlatformVcs.so.6.0.240802"
  IMPORTED_SONAME_RELEASE "libKDevPlatformVcs.so.60"
  )

list(APPEND _cmake_import_check_targets KDev::Vcs )
list(APPEND _cmake_import_check_files_for_KDev::Vcs "${_IMPORT_PREFIX}/lib64/libKDevPlatformVcs.so.6.0.240802" )

# Import target "KDev::Debugger" for configuration "Release"
set_property(TARGET KDev::Debugger APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Debugger PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Sublime;KF6::Notifications;KF6::TextEditor"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKDevPlatformDebugger.so.6.0.240802"
  IMPORTED_SONAME_RELEASE "libKDevPlatformDebugger.so.60"
  )

list(APPEND _cmake_import_check_targets KDev::Debugger )
list(APPEND _cmake_import_check_files_for_KDev::Debugger "${_IMPORT_PREFIX}/lib64/libKDevPlatformDebugger.so.6.0.240802" )

# Import target "KDev::Documentation" for configuration "Release"
set_property(TARGET KDev::Documentation APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Documentation PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Util"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKDevPlatformDocumentation.so.6.0.240802"
  IMPORTED_SONAME_RELEASE "libKDevPlatformDocumentation.so.60"
  )

list(APPEND _cmake_import_check_targets KDev::Documentation )
list(APPEND _cmake_import_check_files_for_KDev::Documentation "${_IMPORT_PREFIX}/lib64/libKDevPlatformDocumentation.so.6.0.240802" )

# Import target "KDev::Serialization" for configuration "Release"
set_property(TARGET KDev::Serialization APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Serialization PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Util"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKDevPlatformSerialization.so.6.0.240802"
  IMPORTED_SONAME_RELEASE "libKDevPlatformSerialization.so.60"
  )

list(APPEND _cmake_import_check_targets KDev::Serialization )
list(APPEND _cmake_import_check_files_for_KDev::Serialization "${_IMPORT_PREFIX}/lib64/libKDevPlatformSerialization.so.6.0.240802" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> kdevelop-24.08.3-x86_64-14.1_KDE6.txz: usr/lib64/cmake/KDevPlatform/KDevPlatformTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDev::Sublime" for configuration "Release"
set_property(TARGET KDev::Sublime APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Sublime PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::KIOWidgets;KF6::I18n;KF6::TextWidgets"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKDevPlatformSublime.so.6.0.240803"
  IMPORTED_SONAME_RELEASE "libKDevPlatformSublime.so.60"
  )

list(APPEND _cmake_import_check_targets KDev::Sublime )
list(APPEND _cmake_import_check_files_for_KDev::Sublime "${_IMPORT_PREFIX}/lib64/libKDevPlatformSublime.so.6.0.240803" )

# Import target "KDev::Interfaces" for configuration "Release"
set_property(TARGET KDev::Interfaces APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Interfaces PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::Service"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKDevPlatformInterfaces.so.6.0.240803"
  IMPORTED_SONAME_RELEASE "libKDevPlatformInterfaces.so.60"
  )

list(APPEND _cmake_import_check_targets KDev::Interfaces )
list(APPEND _cmake_import_check_files_for_KDev::Interfaces "${_IMPORT_PREFIX}/lib64/libKDevPlatformInterfaces.so.6.0.240803" )

# Import target "KDev::Project" for configuration "Release"
set_property(TARGET KDev::Project APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Project PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Serialization;KDev::Sublime;KF6::KIOWidgets;Qt6::Concurrent"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKDevPlatformProject.so.6.0.240803"
  IMPORTED_SONAME_RELEASE "libKDevPlatformProject.so.60"
  )

list(APPEND _cmake_import_check_targets KDev::Project )
list(APPEND _cmake_import_check_files_for_KDev::Project "${_IMPORT_PREFIX}/lib64/libKDevPlatformProject.so.6.0.240803" )

# Import target "KDev::Language" for configuration "Release"
set_property(TARGET KDev::Language APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Language PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Project;KDev::Sublime;KF6::GuiAddons;KF6::TextEditor;KF6::Parts;KF6::Archive;KF6::TextTemplate"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKDevPlatformLanguage.so.6.0.240803"
  IMPORTED_SONAME_RELEASE "libKDevPlatformLanguage.so.60"
  )

list(APPEND _cmake_import_check_targets KDev::Language )
list(APPEND _cmake_import_check_files_for_KDev::Language "${_IMPORT_PREFIX}/lib64/libKDevPlatformLanguage.so.6.0.240803" )

# Import target "KDev::Shell" for configuration "Release"
set_property(TARGET KDev::Shell APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Shell PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Debugger;KDev::Project;KDev::Vcs;KDev::Util;KDev::Documentation;KF6::GuiAddons;KF6::ConfigWidgets;KF6::KIOFileWidgets;KF6::KIOWidgets;KF6::Parts;KF6::Notifications;KF6::NotifyConfig;KF6::TextEditor;KF6::JobWidgets;KF6::ItemViews;KF6::WindowSystem;KF6::TextWidgets;KF6::KCMUtils;KF6::NewStuffWidgets;KF6::Archive;Qt6::DBus"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKDevPlatformShell.so.6.0.240803"
  IMPORTED_SONAME_RELEASE "libKDevPlatformShell.so.60"
  )

list(APPEND _cmake_import_check_targets KDev::Shell )
list(APPEND _cmake_import_check_files_for_KDev::Shell "${_IMPORT_PREFIX}/lib64/libKDevPlatformShell.so.6.0.240803" )

# Import target "KDev::Util" for configuration "Release"
set_property(TARGET KDev::Util APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Util PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Core5Compat;KF6::ItemModels;KF6::GuiAddons"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKDevPlatformUtil.so.6.0.240803"
  IMPORTED_SONAME_RELEASE "libKDevPlatformUtil.so.60"
  )

list(APPEND _cmake_import_check_targets KDev::Util )
list(APPEND _cmake_import_check_files_for_KDev::Util "${_IMPORT_PREFIX}/lib64/libKDevPlatformUtil.so.6.0.240803" )

# Import target "KDev::OutputView" for configuration "Release"
set_property(TARGET KDev::OutputView APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::OutputView PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Interfaces;KDev::Util"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKDevPlatformOutputView.so.6.0.240803"
  IMPORTED_SONAME_RELEASE "libKDevPlatformOutputView.so.60"
  )

list(APPEND _cmake_import_check_targets KDev::OutputView )
list(APPEND _cmake_import_check_files_for_KDev::OutputView "${_IMPORT_PREFIX}/lib64/libKDevPlatformOutputView.so.6.0.240803" )

# Import target "KDev::Vcs" for configuration "Release"
set_property(TARGET KDev::Vcs APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Vcs PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Util;KF6::KIOWidgets;KF6::Parts;KF6::TextWidgets"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKDevPlatformVcs.so.6.0.240803"
  IMPORTED_SONAME_RELEASE "libKDevPlatformVcs.so.60"
  )

list(APPEND _cmake_import_check_targets KDev::Vcs )
list(APPEND _cmake_import_check_files_for_KDev::Vcs "${_IMPORT_PREFIX}/lib64/libKDevPlatformVcs.so.6.0.240803" )

# Import target "KDev::Debugger" for configuration "Release"
set_property(TARGET KDev::Debugger APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Debugger PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Sublime;KF6::Notifications;KF6::TextEditor"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKDevPlatformDebugger.so.6.0.240803"
  IMPORTED_SONAME_RELEASE "libKDevPlatformDebugger.so.60"
  )

list(APPEND _cmake_import_check_targets KDev::Debugger )
list(APPEND _cmake_import_check_files_for_KDev::Debugger "${_IMPORT_PREFIX}/lib64/libKDevPlatformDebugger.so.6.0.240803" )

# Import target "KDev::Documentation" for configuration "Release"
set_property(TARGET KDev::Documentation APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Documentation PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Util"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKDevPlatformDocumentation.so.6.0.240803"
  IMPORTED_SONAME_RELEASE "libKDevPlatformDocumentation.so.60"
  )

list(APPEND _cmake_import_check_targets KDev::Documentation )
list(APPEND _cmake_import_check_files_for_KDev::Documentation "${_IMPORT_PREFIX}/lib64/libKDevPlatformDocumentation.so.6.0.240803" )

# Import target "KDev::Serialization" for configuration "Release"
set_property(TARGET KDev::Serialization APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Serialization PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Util"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKDevPlatformSerialization.so.6.0.240803"
  IMPORTED_SONAME_RELEASE "libKDevPlatformSerialization.so.60"
  )

list(APPEND _cmake_import_check_targets KDev::Serialization )
list(APPEND _cmake_import_check_files_for_KDev::Serialization "${_IMPORT_PREFIX}/lib64/libKDevPlatformSerialization.so.6.0.240803" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
